/****************************************************************************
** Meta object code from reading C++ file 'password.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../keysmith-26.04.2/src/model/password.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'password.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5model15PasswordRequestE_t {};
} // unnamed namespace

template <> constexpr inline auto model::PasswordRequest::qt_create_metaobjectdata<qt_meta_tag_ZN5model15PasswordRequestE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "model::PasswordRequest",
        "passwordRequestChanged",
        "",
        "passwordExists",
        "newPasswordNeeded",
        "passwordAccepted",
        "passwordRejected",
        "passwordStateChanged",
        "setKeyAvailable",
        "setPasswordAvailable",
        "setPasswordRejected",
        "setPreviouslyDefined",
        "setNewPasswordNeeded",
        "providePassword",
        "password",
        "provideBothPasswords",
        "other",
        "firstRun",
        "previouslyDefined",
        "keyAvailable",
        "passwordProvided"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'passwordRequestChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'passwordExists'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newPasswordNeeded'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'passwordAccepted'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'passwordRejected'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'passwordStateChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setKeyAvailable'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setPasswordAvailable'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setPasswordRejected'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setPreviouslyDefined'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setNewPasswordNeeded'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'providePassword'
        QtMocHelpers::MethodData<bool(QString)>(13, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 14 },
        }}),
        // Method 'provideBothPasswords'
        QtMocHelpers::MethodData<bool(QString, QString)>(15, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 14 }, { QMetaType::QString, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'firstRun'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'previouslyDefined'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'keyAvailable'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'passwordProvided'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PasswordRequest, qt_meta_tag_ZN5model15PasswordRequestE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject model::PasswordRequest::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5model15PasswordRequestE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5model15PasswordRequestE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5model15PasswordRequestE_t>.metaTypes,
    nullptr
} };

void model::PasswordRequest::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PasswordRequest *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->passwordRequestChanged(); break;
        case 1: _t->passwordExists(); break;
        case 2: _t->newPasswordNeeded(); break;
        case 3: _t->passwordAccepted(); break;
        case 4: _t->passwordRejected(); break;
        case 5: _t->passwordStateChanged(); break;
        case 6: _t->setKeyAvailable(); break;
        case 7: _t->setPasswordAvailable(); break;
        case 8: _t->setPasswordRejected(); break;
        case 9: _t->setPreviouslyDefined(); break;
        case 10: _t->setNewPasswordNeeded(); break;
        case 11: { bool _r = _t->providePassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->provideBothPasswords((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PasswordRequest::*)()>(_a, &PasswordRequest::passwordRequestChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PasswordRequest::*)()>(_a, &PasswordRequest::passwordExists, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PasswordRequest::*)()>(_a, &PasswordRequest::newPasswordNeeded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PasswordRequest::*)()>(_a, &PasswordRequest::passwordAccepted, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PasswordRequest::*)()>(_a, &PasswordRequest::passwordRejected, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PasswordRequest::*)()>(_a, &PasswordRequest::passwordStateChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->firstRun(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->previouslyDefined(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->keyAvailable(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->passwordProvided(); break;
        default: break;
        }
    }
}

const QMetaObject *model::PasswordRequest::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *model::PasswordRequest::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5model15PasswordRequestE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int model::PasswordRequest::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void model::PasswordRequest::passwordRequestChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void model::PasswordRequest::passwordExists()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void model::PasswordRequest::newPasswordNeeded()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void model::PasswordRequest::passwordAccepted()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void model::PasswordRequest::passwordRejected()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void model::PasswordRequest::passwordStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
