// This file is generated by kconfig_compiler_kf6 from stateconfig.kcfg.
// All changes you do to this file will be lost.
#ifndef STATECONFIG_H
#define STATECONFIG_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class StateConfig : public KConfigSkeleton
{
  Q_OBJECT
  public:

    static StateConfig *self();
    ~StateConfig() override;

    /**
      Set Last 
    */
    static
    void setLastCameraId( const QString & v )
    {
      if (v != self()->mLastCameraId && !self()->isLastCameraIdImmutable()) {
        self()->mLastCameraId = v;
        Q_EMIT self()->LastCameraIdChanged();
      }
    }

    Q_PROPERTY(QString lastCameraId READ lastCameraId WRITE setLastCameraId NOTIFY LastCameraIdChanged)
    Q_PROPERTY(bool isLastCameraIdImmutable READ isLastCameraIdImmutable CONSTANT)
    /**
      Get Last 
    */
    static
    QString lastCameraId()
    {
      return self()->mLastCameraId;
    }

    /**
      Is Last  Immutable
    */
    static
    bool isLastCameraIdImmutable()
    {
      return self()->isImmutable( QStringLiteral( "LastCameraId" ) );
    }


    enum {
      signalLastCameraIdChanged = 1
    };

  Q_SIGNALS:
    void LastCameraIdChanged();

  private:
    void itemChanged(quint64 signalFlag);

  protected:
    StateConfig(QObject *parent = nullptr);
    friend class StateConfigHelper;


    // Camera
    QString mLastCameraId;
    static QString defaultLastCameraIdValue_helper();
};

#endif

