/****************************************************************************
** Meta object code from reading C++ file 'accounts.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../keysmith-26.04.2/src/model/accounts.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'accounts.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5model11AccountViewE_t {};
} // unnamed namespace

template <> constexpr inline auto model::AccountView::qt_create_metaobjectdata<qt_meta_tag_ZN5model11AccountViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "model::AccountView",
        "tokenChanged",
        "",
        "remove",
        "recompute",
        "advanceCounter",
        "by",
        "setCounter",
        "value",
        "millisecondsLeftForToken",
        "isHotp",
        "isTotp",
        "name",
        "token",
        "issuer",
        "counter",
        "epoch",
        "timeStep",
        "offset",
        "tokenLength",
        "hash"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'tokenChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'remove'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'recompute'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'advanceCounter'
        QtMocHelpers::SignalData<void(quint64)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 6 },
        }}),
        // Signal 'advanceCounter'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'setCounter'
        QtMocHelpers::SignalData<void(quint64)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 8 },
        }}),
        // Method 'millisecondsLeftForToken'
        QtMocHelpers::MethodData<qint64() const>(9, 2, QMC::AccessPublic, QMetaType::LongLong),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isHotp'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isTotp'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'token'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'issuer'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'counter'
        QtMocHelpers::PropertyData<quint64>(15, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 0),
        // property 'epoch'
        QtMocHelpers::PropertyData<QDateTime>(16, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'timeStep'
        QtMocHelpers::PropertyData<uint>(17, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'offset'
        QtMocHelpers::PropertyData<uint>(18, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tokenLength'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hash'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AccountView, qt_meta_tag_ZN5model11AccountViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject model::AccountView::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5model11AccountViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5model11AccountViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5model11AccountViewE_t>.metaTypes,
    nullptr
} };

void model::AccountView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AccountView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->tokenChanged(); break;
        case 1: _t->remove(); break;
        case 2: _t->recompute(); break;
        case 3: _t->advanceCounter((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 4: _t->advanceCounter(); break;
        case 5: _t->setCounter((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 6: { qint64 _r = _t->millisecondsLeftForToken();
            if (_a[0]) *reinterpret_cast<qint64*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AccountView::*)()>(_a, &AccountView::tokenChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountView::*)()>(_a, &AccountView::remove, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountView::*)()>(_a, &AccountView::recompute, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountView::*)(quint64 )>(_a, &AccountView::advanceCounter, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountView::*)(quint64 )>(_a, &AccountView::setCounter, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isHotp(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isTotp(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->token(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->issuer(); break;
        case 5: *reinterpret_cast<quint64*>(_v) = _t->counter(); break;
        case 6: *reinterpret_cast<QDateTime*>(_v) = _t->epoch(); break;
        case 7: *reinterpret_cast<uint*>(_v) = _t->timeStep(); break;
        case 8: *reinterpret_cast<uint*>(_v) = _t->offset(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->tokenLength(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->hash(); break;
        default: break;
        }
    }
}

const QMetaObject *model::AccountView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *model::AccountView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5model11AccountViewE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int model::AccountView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void model::AccountView::tokenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void model::AccountView::remove()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void model::AccountView::recompute()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void model::AccountView::advanceCounter(quint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 5
void model::AccountView::setCounter(quint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN5model22SimpleAccountListModelE_t {};
} // unnamed namespace

template <> constexpr inline auto model::SimpleAccountListModel::qt_create_metaobjectdata<qt_meta_tag_ZN5model22SimpleAccountListModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "model::SimpleAccountListModel",
        "loadedChanged",
        "",
        "errorChanged",
        "added",
        "account",
        "removed",
        "handleError",
        "addAccount",
        "model::AccountInput*",
        "input",
        "isAccountStillAvailable",
        "name",
        "issuer",
        "rowCount",
        "QModelIndex",
        "parent",
        "data",
        "QVariant",
        "index",
        "role",
        "loaded",
        "error",
        "NonStandardRoles",
        "AccountRole",
        "TOTPAlgorithms",
        "Sha1",
        "Sha256",
        "Sha512"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'loadedChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'added'
        QtMocHelpers::SlotData<void(const QString &)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'removed'
        QtMocHelpers::SlotData<void(const QString &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'handleError'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'addAccount'
        QtMocHelpers::MethodData<void(model::AccountInput *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Method 'isAccountStillAvailable'
        QtMocHelpers::MethodData<bool(const QString &, const QString &) const>(11, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 13 },
        }}),
        // Method 'rowCount'
        QtMocHelpers::MethodData<int(const QModelIndex &) const>(14, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Method 'rowCount'
        QtMocHelpers::MethodData<int() const>(14, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int),
        // Method 'data'
        QtMocHelpers::MethodData<QVariant(const QModelIndex &, int) const>(17, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { 0x80000000 | 15, 19 }, { QMetaType::Int, 20 },
        }}),
        // Method 'data'
        QtMocHelpers::MethodData<QVariant(const QModelIndex &) const>(17, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 18, {{
            { 0x80000000 | 15, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'loaded'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'error'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'NonStandardRoles'
        QtMocHelpers::EnumData<enum NonStandardRoles>(23, 23, QMC::EnumFlags{}).add({
            {   24, NonStandardRoles::AccountRole },
        }),
        // enum 'TOTPAlgorithms'
        QtMocHelpers::EnumData<enum TOTPAlgorithms>(25, 25, QMC::EnumFlags{}).add({
            {   26, TOTPAlgorithms::Sha1 },
            {   27, TOTPAlgorithms::Sha256 },
            {   28, TOTPAlgorithms::Sha512 },
        }),
    };
    return QtMocHelpers::metaObjectData<SimpleAccountListModel, qt_meta_tag_ZN5model22SimpleAccountListModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject model::SimpleAccountListModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5model22SimpleAccountListModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5model22SimpleAccountListModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5model22SimpleAccountListModelE_t>.metaTypes,
    nullptr
} };

void model::SimpleAccountListModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SimpleAccountListModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->loadedChanged(); break;
        case 1: _t->errorChanged(); break;
        case 2: _t->added((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->removed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->handleError(); break;
        case 5: _t->addAccount((*reinterpret_cast<std::add_pointer_t<model::AccountInput*>>(_a[1]))); break;
        case 6: { bool _r = _t->isAccountStillAvailable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { int _r = _t->rowCount((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 8: { int _r = _t->rowCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: { QVariant _r = _t->data((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 10: { QVariant _r = _t->data((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< model::AccountInput* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SimpleAccountListModel::*)()>(_a, &SimpleAccountListModel::loadedChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SimpleAccountListModel::*)()>(_a, &SimpleAccountListModel::errorChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->loaded(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->error(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setError(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *model::SimpleAccountListModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *model::SimpleAccountListModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5model22SimpleAccountListModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int model::SimpleAccountListModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void model::SimpleAccountListModel::loadedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void model::SimpleAccountListModel::errorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN5model23SortedAccountsListModelE_t {};
} // unnamed namespace

template <> constexpr inline auto model::SortedAccountsListModel::qt_create_metaobjectdata<qt_meta_tag_ZN5model23SortedAccountsListModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "model::SortedAccountsListModel"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SortedAccountsListModel, qt_meta_tag_ZN5model23SortedAccountsListModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject model::SortedAccountsListModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5model23SortedAccountsListModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5model23SortedAccountsListModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5model23SortedAccountsListModelE_t>.metaTypes,
    nullptr
} };

void model::SortedAccountsListModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SortedAccountsListModel *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *model::SortedAccountsListModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *model::SortedAccountsListModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5model23SortedAccountsListModelE_t>.strings))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int model::SortedAccountsListModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN5model20AccountNameValidatorE_t {};
} // unnamed namespace

template <> constexpr inline auto model::AccountNameValidator::qt_create_metaobjectdata<qt_meta_tag_ZN5model20AccountNameValidatorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "model::AccountNameValidator",
        "issuerChanged",
        "",
        "accountsChanged",
        "validateAvailabilityChanged",
        "issuer",
        "accounts",
        "model::SimpleAccountListModel*",
        "validateAvailability"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'issuerChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'accountsChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'validateAvailabilityChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'issuer'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'accounts'
        QtMocHelpers::PropertyData<model::SimpleAccountListModel*>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'validateAvailability'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AccountNameValidator, qt_meta_tag_ZN5model20AccountNameValidatorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject model::AccountNameValidator::staticMetaObject = { {
    QMetaObject::SuperData::link<QValidator::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5model20AccountNameValidatorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5model20AccountNameValidatorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5model20AccountNameValidatorE_t>.metaTypes,
    nullptr
} };

void model::AccountNameValidator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AccountNameValidator *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->issuerChanged(); break;
        case 1: _t->accountsChanged(); break;
        case 2: _t->validateAvailabilityChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AccountNameValidator::*)()>(_a, &AccountNameValidator::issuerChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountNameValidator::*)()>(_a, &AccountNameValidator::accountsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountNameValidator::*)()>(_a, &AccountNameValidator::validateAvailabilityChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< model::SimpleAccountListModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->issuer(); break;
        case 1: *reinterpret_cast<model::SimpleAccountListModel**>(_v) = _t->accounts(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->validateAvailability(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setIssuer(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setAccounts(*reinterpret_cast<model::SimpleAccountListModel**>(_v)); break;
        case 2: _t->setValidateAvailability(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *model::AccountNameValidator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *model::AccountNameValidator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5model20AccountNameValidatorE_t>.strings))
        return static_cast<void*>(this);
    return QValidator::qt_metacast(_clname);
}

int model::AccountNameValidator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QValidator::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void model::AccountNameValidator::issuerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void model::AccountNameValidator::accountsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void model::AccountNameValidator::validateAvailabilityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
